#
# spec file for package attractmode
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           attractmode
Version:        2.2.1
Release:        lp150.1.12
Summary:        A graphical frontend for emulators
License:        GPL-3.0
Group:          System/Emulators/Other
Url:            https://attractmode.org
Source0:        https://github.com/mickelson/attract/archive/v%{version}/attract-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM appdata-desktop.patch - https://github.com/mickelson/attract/pull/319
Patch0:         appdata-desktop.patch
# PATCH-FIX-UPSTREAM fix-no-return-in-nonvoid-function.patch - https://github.com/mickelson/attract/pull/321
Patch1:         fix-no-return-in-nonvoid-function.patch
# PATCH-FIX-UPSTREAM fix-install-target.patch - https://github.com/mickelson/attract/pull/320
Patch2:         fix-install-target.patch
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  libjpeg8-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sfml-audio)
BuildRequires:  pkgconfig(sfml-graphics)
BuildRequires:  pkgconfig(sfml-system)
BuildRequires:  pkgconfig(xcb-xinerama)
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils

%description
Attract-Mode is a graphical frontend for command line emulators such as MAME,
MESS and Nestopia. It hides the underlying operating system and is intended to
be controlled with a joystick, gamepad or spinner, making it ideal for use
in arcade cabinets.

%prep
%setup -q -n attract-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
make %{?_smp_mflags} EXTRA_CFLAGS="%{optflags}" prefix=%{_prefix}

%install
%make_install prefix=%{_prefix}

# Install icon and appdata- and .desktop-file
install -Dm644 util/linux/attract-mode.appdata.xml %{buildroot}%{_datadir}/appdata/attract-mode.appdata.xml
install -Dm644 util/linux/attract-mode.png         %{buildroot}%{_datadir}/pixmaps/attract-mode.png
install -Dm644 util/linux/attract-mode.desktop     %{buildroot}%{_datadir}/applications/attract-mode.desktop

# Hardlinks so users can copy it
%fdupes %{buildroot}%{_datadir}/attract

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc Readme.md
%if ( 0%{?suse_version} == 1315 && 0%{?sle_version} == 120100 ) || ! 0%{?is_opensuse}
# Fix for Leap 42.1 and SLE (TODO: Remove when 42.1 is out of maintenance)
%dir %{_datadir}/appdata
%doc License.txt
%else
%license License.txt
%endif
%{_bindir}/attract
%{_datadir}/attract
%{_datadir}/pixmaps/attract-mode.png
%{_datadir}/applications/attract-mode.desktop
%{_datadir}/appdata/attract-mode.appdata.xml

%changelog
* Thu Mar  2 2017 rpm@fthiessen.de
- Use bundled .desktop file
- Compile with correct prefix (needed for DATA_PATH in fe_settings)
  and with optflags
  * Added fix-no-return-in-nonvoid-function.patch to fix
    nonvoid functions without return valuu.
- Workaround for missing appdata directory on Leap 42.1
- Reported appdata file upstream
  * appdata-desktop.patch
- Added to fix fix-install-target.patch install-target
  of the makefile.
* Thu Feb  9 2017 luke.nukem.jones@gmail.com
- Update to version 2.2.1
    + [linux] fixes for multimonitor mode with X11
    + [rpi] Misc. cleanup of emulation launching on the RPi
    + Added a description of the default controls to the readme
    + Fix move speed in config menus when key held down
    + Fix freetype2 header not found during compile
    + [linux] Added --console cmdline option to enable script from console
    + Improved combo key handling, added more initial key mappings
    + Default "Confirm Favourites" value is now "true"
    + Fix audio volume changing for layout sounds after running emulator
    + Add cn entry in en.msg
    + [linux] Smoother transition to emulator from 'fullscreen mode'
    + Added "Working Directory" emulation setting
    + Minor reorder of options in the misc. config menu
    + Issue #250 - Fix improper handling of "Upos" joystick axis
  + cn.msg
  + Create Linux desktop entry
  + Support for wheel fade
* Sun Nov 20 2016 luke.nukem.jones@gmail.com
- Issue #250 - Fix improper handling of "Upos" joystick axis
- Added scraping of game overview text from thegamesdb.net
- Added configure option to disable scraping of mamedb.com
- Fixed "Toggle Layout" when used on the displays menu layout
- Added layout options configuration for 'Displays Menu' layout
- [rpi] Issue #266 - Fix for keypresses being cached w/ sfml-pi build (non-X11)
- Added ability to set image origin in scripts (for centre rotations etc)
- Added customized layouts for the diplays menu/system selection menu
- Issue #264 - fixed SWF crash when unimplemented actionscript constant types encountered
- Added a no border window mode
- Issue #258 - Windows 10 v.1607 task bar fix (Fullscreen Mode)
- Limit the squirrel script functions available when gathering plugin descriptions
- Added an "RGB Movie" mode to the screensaver
- Updated the "Keyboard Search" plugin so "Back" clears the current search
- [linux] Fixed potential hang when waiting for emulator exit
- Issue #262 - Fixed sound volume setting after game return
- Added ability to generate multi-emulator romlists to the configuration interface.
- Misc. fixes to internationalization, updated italian translation
- Minor changes to mutex usage in media player
- Added ability to set a custom executable and arguments for each game
- Added an "Edit Game" action
- Fixed jumping cursor bug when using keyboard to edit
- Refactor of thegamesdb_scraper()
- Updates to the italian translation (P. Ghezzo)
- Fix cancel using the back button during scraping
- Added basic ability to edit text using a control pad (in config mode)
- [rpi] Default to "Fill Screen Mode" on the Raspberry Pi
- [linux] fix focus issues with exit hotkeys and "fullscreen mode"
- Issue #246 - Added ability to import mame listsoftware format xml
- Issue #247 - fixed the "Show in cycle" display setting
- Fixed memory leak when video frames are dropped
- Issue #245 - fixed fade module getting stuck when no image found
- [rpi] Issue #236 - Initial addition of MMAL video decoder support
- Issue #231 - revert to not randomizing artwork
- Issue #232 - fixed scraping of random system artworks
- Added Italian translation (author: P. Ghezzo)
* Sat Jul 16 2016 luke.nukem.jones@gmail.com
- Use the correct license SPDX
- Switch to pkgconfig for rpm build
- v2.1.0.
- Andrew Mickelson (14 commits)
  * Version 2.1.0
  * Issue #227 - randomly select artwork when matches are available from multiple paths
  * Issue #228 - Fixed a couple of bugs when menus (exit, etc) are triggered by a joystick move
  * [windows] Issue #199 - Console hiding is now configurable in attract.cfg. Default is off.
  * [linux] Issue #228 - Fix "Z" and "R" joystick axes
  * Added 6 second timeout when mapping a new input.
  * Issue #225 - fix --build-romlist mame --full when no files found
  * Issue #124 - Added support for hotkey combos
  * [linux] Fixed emulator 'exit hotkey'
  * Issue #167 - Filter by button count.
  * Issue #216 - separate UI menu navigation (up.down,left,right,back,sel)
  * [linux,rpi] Fixes when running emulator (in "Fullscreen Mode")
  * [rpi] Allow changing the window mode setting on the rpi version
  * Issue #215 - fix crash in fe.get_art() when image is missing
- Jeffrey Clark (3 commits)
  * fix build when TR1 enabled
  * support for libavcodec < 55.16
  * replace deprecated AVPicture
